@@ -15,7 +15,7 @@ from puddleobjects import PuddleConfig, PuddleCombo
 from audioinfo import INFOTAGS, READONLY, usertags, isempty
 from functools import partial
 from constants import (TEXT, COMBO, CHECKBOX, SEPARATOR, 
-    SAVEDIR, ACTIONDIR, BLANK)
+    SAVEDIR, CONFIGDIR, ACTIONDIR, BLANK)
 from util import (open_resourcefile, PluginFunction, escape_html,
     translate, pprint_tag)
 import functions_dialogs
@@ -23,7 +23,7 @@ from puddlestuff.puddleobjects import ShortcutEditor
 from puddletag import status
 
 READONLY = list(READONLY)
-FUNC_SETTINGS = os.path.join(SAVEDIR, 'function_settings')
+FUNC_SETTINGS = os.path.join(CONFIGDIR, 'function_settings')
 
 FIELDS_TOOLTIP = translate('Functions Dialog',
     """<p>Fields that will
@@ -876,11 +876,12 @@ class ActionWindow(QDialog):
                     enumerate(order)])
                 files = glob(os.path.join(ACTIONDIR, u'*.action'))
                 order = {}
-                for f in files:
+                for i, action_fn in enumerate(files):
                     try:
-                        order[old_order[basename(f)]] = f
+                        order[old_order[basename(action_fn)]] = action_fn
                     except KeyError:
-                        pass
+                        if not old_order:
+                            order[i] = action_fn
                 order = [z[1] for z in sorted(order.items())]
                 set_value('order', order)
 
