@@ -45,6 +45,7 @@ def arglen_error(e, passed, function, to_raise = True):
     varnames = function.func_code.co_varnames[:function.func_code.co_argcount]
     args_len = len(passed)
     param_len = len(varnames)
+    message = None
     if args_len > param_len:
         message = translate('Functions',
             'At most %1 arguments expected. %2 given.')
@@ -56,7 +57,10 @@ def arglen_error(e, passed, function, to_raise = True):
             'At least %1 arguments expected. %2 given.')
     else:
         raise e
-    message = message.arg(unicode(param_len)).arg(unicode(args_len))
+    if message is not None:
+        message = message.arg(unicode(param_len)).arg(unicode(args_len))
+    else:
+        raise e
     if to_raise:
         raise ParseError(message)
     else:
@@ -73,7 +77,7 @@ def convert_actions(dirpath, new_dir):
     for filename in glob.glob(path_join(dirpath, '*.action')):
         funcs, name = get_old_action(filename)
         os.rename(filename, path_join(backup, basename(filename)))
-        save_action(path_join(new_dir, basename(filename)), name, funcs)
+        save_macro(path_join(new_dir, basename(filename)), name, funcs)
 
 def filenametotag(pattern, filename, checkext = False, split_dirs=True):
     """Retrieves tag values from your filename
@@ -155,7 +159,14 @@ def load_macro_info(filename):
     cparser = PuddleConfig(filename)
     funcs = []
     name = cparser.get('info', 'name', u'')
-    for section in cparser.sections():
+
+    def get_func_index(funcname):
+        if funcname.startswith('Func'):
+            return int(funcname[4:].strip())
+        else:
+            return funcname
+
+    for section in sorted(cparser.sections(), key=get_func_index):
         if section.startswith(u'Func'):
             get = partial(cparser.get, section)
             func_name = get(FUNC_NAME, u'')
@@ -171,7 +182,7 @@ def load_macro_info(filename):
             newargs = []
             for i, (control, arg) in enumerate(zip(func.controls, arguments)):
                 if control == CHECKBOX:
-                    if arg == u'False':
+                    if arg == False or arg == u'False':
                         newargs.append(False)
                     else:
                         newargs.append(True)
@@ -244,7 +255,7 @@ def get_function_arguments(funcname, func, arguments, reserved, fmt=True, *dicts
             topass[param] = arg
         elif param.startswith('n_'):
             try:
-                if float(arg):
+                if float(arg) or float(arg) == 0:
                     topass[param] = Decimal(arg)
             except ValueError:
                 raise ParseError(SYNTAX_ARG_ERROR % (funcname, no + 1))
@@ -361,11 +372,13 @@ def parsefunc(s, m_audio, s_audio=None, state=None, extra=None, ret_i=False, pat
     tags = s_audio.copy()
     tags.update(state)
     tags.update(extra if extra is not None else {})
+    escape_chars = set('()$%\\,')
 
     br_error = translate('Errors', 'No closing bracket found.')
 
     paths = []
 
+    
     i = 0
     while 1:
         try:
@@ -376,7 +389,7 @@ def parsefunc(s, m_audio, s_audio=None, state=None, extra=None, ret_i=False, pat
             if token:
                 tokens.append(replacevars(u''.join(token), tags))
             break
-
+        
         if c == u'"' and not escape:
             if in_func:
                 token.append(c)
@@ -386,13 +399,24 @@ def parsefunc(s, m_audio, s_audio=None, state=None, extra=None, ret_i=False, pat
             i += 1
             escape = False
             continue
+        elif escape:
+            token.append(c)
+            escape = False
+            i += 1
+            continue
         elif in_quote:
             token.append(c)
         elif c == u'\\' and not escape:
             escape = True
             i += 1
-            if not in_func:
+            try:
+                next_char = s[i]
+            except IndexError:
+                next_char = None
+
+            if not in_func or (next_char not in escape_chars):
                 token.append(c)
+                escape = False
             continue
         elif c == u'$' and not (escape or (field_open >= 0)):
             func_name = re.search(u'^\$(\w+)\(', s[i:])
@@ -518,7 +542,11 @@ def replacevars(pattern, *dicts):
     escape = False
 
     for i, c in enumerate(pattern):
-        if c == u'\\' and not escape:
+        try:
+            next_char = pattern[i + 1]
+        except IndexError:
+            next_char = None
+        if c == u'\\' and next_char == '"' and not escape:
             escape = True
             continue
         elif escape:
@@ -611,7 +639,7 @@ def apply_macros(macros, audio, state, fields=None):
 def runQuickAction(funcs, audio, state, tag):
     """Same as runAction, except that all funcs are 
     applied not in the values stored but on audio[tag]."""
-    return runAction(funcs, audio, state, tag)
+    return apply_macros(funcs, audio, state, tag)
 
 def save_macro(filename, name, funcs):
     f = open(filename, 'w')
@@ -826,7 +854,7 @@ class Function:
             return
 
         if not first_arg.startswith('m_'):
-            text = m_text
+            text = [to_string(z) for z in to_list(m_text)]
             ret = []
             for z in m_text:
                 topass[first_arg] = z
@@ -875,8 +903,7 @@ class Macro(object):
             self.load(filename)
 
     def apply_action(self, audio, state=None, fields=None):
-
-        return run_action(self.actions, audio, state, fields)
+        return apply_macros(self.actions, audio, state, fields)
 
     def copy(self):
         m = Macro()
@@ -893,4 +920,4 @@ class Macro(object):
             filename = self.filename
     
         save_macro(filename, self.name, self.actions)
-        
\ No newline at end of file
+        
